
==================================
Welcome to csdmpy's documentation!
==================================

.. only:: html

    .. image:: https://travis-ci.org/DeepanshS/csdmpy.svg?branch=master
        :target: https://travis-ci.org/DeepanshS/csdmpy

    .. image:: https://readthedocs.org/projects/csdmpy/badge/?version=stable
        :target: https://csdmpy.readthedocs.io/en/stable/?badge=stable
        :alt: Documentation Status

    .. image:: https://img.shields.io/badge/License-BSD%203--Clause-blue.svg
        :target: https://opensource.org/licenses/BSD-3-Clause

    .. image:: https://img.shields.io/github/issues-raw/deepanshs/csdmpy
        :alt: GitHub issues

    .. image:: https://img.shields.io/github/release-pre/deepanshs/csdmpy
        :alt: GitHub release

    .. image:: https://badge.fury.io/py/csdmpy.svg
        :target: https://badge.fury.io/py/csdmpy

    .. image:: https://img.shields.io/lgtm/alerts/g/DeepanshS/csdmpy.svg?logo=lgtm&logoWidth=18
        :target: https://lgtm.com/projects/g/DeepanshS/csdmpy/alerts/
        :alt: Total alerts

    .. image:: https://img.shields.io/lgtm/grade/python/g/DeepanshS/csdmpy.svg?logo=lgtm&logoWidth=18
        :target: https://lgtm.com/projects/g/DeepanshS/csdmpy/context:python
        :alt: Language grade: Python

----

The `csdmpy` package is the Python support for the core scientific
dataset (CSD) model file exchange-format.
The package is based on the core scientific dataset (CSD) model, which is
designed as a building block in the development of a more sophisticated
portable scientific dataset file standard.
The CSD model is capable of handling a wide variety of
scientific datasets both within and across disciplinary fields.

The main objective of this python package is to facilitate an easy import and
export of the CSD model serialized files for Python users. The
package utilizes Numpy library and, therefore, offers the end-users versatility
to process or visualize the imported datasets with any third-party package(s)
compatible with Numpy.

----

.. only:: latex

    **The sample CSDM compliant files used in this documentation are available**
    `online <https://osu.box.com/s/bq10pc5jyd3mu67vqvhw4xmrqgsd0x8u>`_.

.. only:: html

    **The sample CSDM compliant files used in this documentation are available online.**

    .. image:: https://img.shields.io/badge/Download-CSDM%20sample%20files-blueviolet
        :target: https://osu.box.com/s/bq10pc5jyd3mu67vqvhw4xmrqgsd0x8u

----

.. toctree::
    :maxdepth: 2
    :caption: Table of Contents

    CSD_model
    installation
    getting_started
    examples/examples
    startFromScratch/start
    referenceAPI

.. only:: html

    Indices and tables
    ^^^^^^^^^^^^^^^^^^

    * :ref:`genindex`
    * :ref:`modindex`
    * :ref:`search`
